<a href="http://pythoninchemistry.org/pylj"><img src="https://github.com/arm61/pylj/blob/master/logo/logo.png?raw=true" width= "80%"/></a>

## Visit the [pylj](http://pythoninchemistry.org/pylj) webpage for more information about pylj. 

<p><a href="https://zenodo.org/badge/latestdoi/119863480"><img src="https://zenodo.org/badge/119863480.svg" alt="DOI"></a><a href='http://pylj.readthedocs.io/en/latest/?badge=latest'><img src='https://readthedocs.org/projects/pylj/badge/?version=latest' alt='Documentation Status' /></a></p>

